__version__ = '1.8.1'
__author__ = 'Lennard Krause'
__authors__ = ['Lennard Krause', 'Frederik H. Gjørup', 'Mads R. V. Jørgensen']
__email__ = 'lkrause@chem.au.dk'
__date__ = '30.05.2024'
__year__ = '2024'